@@ -52,8 +52,8 @@ void ConfigDialogPrivate::init()
     Q_Q(ConfigDialog);
     ui->setupUi(q);
 
-    QObject::connect(ui->buttons, &QDialogButtonBox::clicked,
-                     [=](QAbstractButton* button) { dialogButtonsAction(button); }
+    QObject::connect(ui->buttons, &QDialogButtonBox::clicked, q,
+                     [this](QAbstractButton* button) { dialogButtonsAction(button); }
     );
 
     ui->moduleList->setVisible(false);
@@ -130,7 +130,7 @@ void ConfigDialog::addPage(QWidget* page, const QString& name, const QStringList
      */
     if (page->layout())
     {
-        page->layout()->setMargin(0);
+        page->layout()->setContentsMargins(QMargins());
     }
 
     QStringList icons = QStringList(iconNames) << QL1S("application-x-executable");
